@@ -14,11 +14,15 @@
 #define OUTPUT_BUFFER_SIZE (WRMT_BUFFER_SIZE+1)
 #define INPUT_BUFFER_SIZE (WRMT_BUFFER_SIZE+1)
 
-@interface WiiRemoteImplement : NSObject <IOBluetoothL2CAPChannelDelegate>
+@interface WiiRemoteImplement : NSObject
 {
 	IOBluetoothDevice *device;
 	IOBluetoothL2CAPChannel *controlChannel;
 	IOBluetoothL2CAPChannel *interruptChannel;
+	id controlChannelHandler;
+	id interruptChannelHandler;
+	BOOL controlChannelState;
+	BOOL interruptChannelState;
 	unsigned char inputBuffer[INPUT_BUFFER_SIZE];
 	unsigned char outputBuffer[OUTPUT_BUFFER_SIZE];
 }
